@@ -4,7 +4,7 @@ use Class::LazyLoad;
 
 sub new
 {
-    bless \my $x, shift;
+    bless \my ($x), shift;
 }
 
 sub hello
